@@ -7,7 +7,7 @@ use std::path::PathBuf;
 use sysinfo::{ProcessExt, ProcessStatus, SystemExt};
 
 #[derive(Parser, Debug, Clone)]
-#[clap(version = "0.4.11")]
+#[clap(version = "0.4.15")]
 #[clap(about = "A command line tool to record process and system performance data.")]
 pub struct Opts {
     #[clap(short, long, multiple_values = true)]
@@ -24,6 +24,8 @@ pub struct Opts {
     pub category: Vec<Category>,
     #[clap(short, long)]
     recurse_children: bool,
+    #[clap(long, default_value_t = 0)]
+    pub skip: usize,
 }
 
 impl Opts {
